[Schmitzm-commits] r1282 - in trunk: src/schmitzm/lang src_junit/schmitzm/lang src_junit/schmitzm/lang/resource/locales

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Wed Nov 17 12:02:15 CET 2010


Author: mojays
Date: 2010-11-17 12:02:14 +0100 (Wed, 17 Nov 2010)
New Revision: 1282

Modified:
   trunk/src/schmitzm/lang/ResourceProviderOperator.java
   trunk/src_junit/schmitzm/lang/ResourceProviderTest.java
   trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle.properties
   trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_de.properties
   trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_fr.properties
   trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_it.properties
   trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_ru.properties
Log:
ResourceProviderOperator: overwriting original files; removed keys in ".removedKeys.properties"

Modified: trunk/src/schmitzm/lang/ResourceProviderOperator.java
===================================================================
--- trunk/src_junit/schmitzm/lang/ResourceProviderTest.java	2010-11-17 11:01:16 UTC (rev 1281)
+++ trunk/src_junit/schmitzm/lang/ResourceProviderTest.java	2010-11-17 11:02:14 UTC (rev 1282)
@@ -13,10 +13,20 @@
 import org.apache.log4j.Logger;
 import org.apache.log4j.SimpleLayout;
 import org.apache.log4j.WriterAppender;
+import org.junit.Ignore;
 import org.junit.Test;
 
 public class ResourceProviderTest {
 
+    @Test
+    @Ignore
+    public void testResourceProviderOperatorTest() throws Exception {
+      ResourceProviderOperator.main( new String[] {
+              "-cff",
+              "src_junit/schmitzm/lang/ResourceProviderOperator.cfg"
+      });
+    }
+  
 	@Test
 	public void testGetWrongKeyLogging() {
 		Logger.getRootLogger().removeAllAppenders();

Modified: trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle.properties
===================================================================
--- trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle.properties	2010-11-17 11:01:16 UTC (rev 1281)
+++ trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle.properties	2010-11-17 11:02:14 UTC (rev 1282)
@@ -1,48 +1,47 @@
-##########
-#Copyright (c) 2009 Martin O. J. Schmitz.
-#
-#This file is part of the SCHMITZM library - a collection of utility 
-#classes based on Java 1.6, focusing (not only) on Java Swing 
-#and the Geotools library.
-#
-#The SCHMITZM project is hosted at:
-#http://wald.intevation.org/projects/schmitzm/
-#
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU Lesser General Public License
-#as published by the Free Software Foundation; either version 3
-#of the License, or (at your option) any later version.
-#
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-#
-#You should have received a copy of the GNU Lesser General Public License (license.txt)
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#or try this link: http://www.gnu.org/licenses/lgpl.html
-#
-#Contributors:
-#    Martin O. J. Schmitz - initial API and implementation
-#    Stefan A. Tzeggai - additional utility classes
-REMOVEME_OperationTree.Integer=Integer
+##########
+#Copyright (c) 2009 Martin O. J. Schmitz.
+#
+#This file is part of the SCHMITZM library - a collection of utility 
+#classes based on Java 1.6, focusing (not only) on Java Swing 
+#and the Geotools library.
+#
+#The SCHMITZM project is hosted at:
+#http://wald.intevation.org/projects/schmitzm/
+#
+#This program is free software; you can redistribute it and/or
+#modify it under the terms of the GNU Lesser General Public License
+#as published by the Free Software Foundation; either version 3
+#of the License, or (at your option) any later version.
+#
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#
+#You should have received a copy of the GNU Lesser General Public License (license.txt)
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+#or try this link: http://www.gnu.org/licenses/lgpl.html
+#
+#Contributors:
+#    Martin O. J. Schmitz - initial API and implementation
+#    Stefan A. Tzeggai - additional utility classes
+
+#Revised by ResourceProviderOperator (Unused keys removed)
+#Wed Nov 17 11:58:09 CET 2010
+OperationTree.err.UnexpectedBracket=Bracket ${0} can not close ${1}
 OperationTree.Number=Number
-OperationTree.err.ParseErrorMess=Parse-Error at "${0}": ${1}
-OperationTree.err.UnexpectedEOR=Unexpected end of rule!
-OperationTree.err.UnexpectedError=Unexpected error!
+OperationTree.err.UnexpectedEOR=Unexpected end of rule\!
+OperationTree.err.UnknownNode=Unknown operation tree node\: ${0}
 OperationTree.err.TokenNotExpected=${0} not expected
-OperationTree.err.MoreParamsExpected=${0} more function parameters expected. Bracket can not close!
-OperationTree.err.UnexpectedBracket=Bracket ${0} can not close ${1}
-OperationTree.err.BracketsNotClosed=Bracket(s) not closed: ${0}
+OperationTree.err.LessParams2=${0} function parameters expected\: ${1}(..)
+OperationTree.err.IllegalCharacter=Illegal character '${0}' (${1} expected)
+OperationTree.err.UnexpectedError=Unexpected error\!
+OperationTree.err.UnknownAliasOperator=Unknown alias operator\: ${0}
+OperationTree.err.UnknownOperator=Unknown operator\: ${0}
 OperationTree.err.IllegalOperator=Illegal operator ${0}
+OperationTree.err.ParseErrorMess=Parse-Error at "${0}"\: ${1}
 OperationTree.err.IllegalOperatorSyntax=Illegal ${0} syntax '${1}'
-REMOVEME_OperationTree.err.ParamSepExpected=Parameter-Separator expected
-OperationTree.err.IllegalCharacter=Illegal character '${0}' (${1} expected)
-
-OperationTree.err.UnknownNode=Unknown operation tree node: ${0}
-OperationTree.err.UnknownOperator=Unknown operator: ${0}
-OperationTree.err.UnknownAliasOperator=Unknown alias operator: ${0}
-REMOVEME_OperationTree.err.LessParams1=At least ${0} function parameters expected: ${1}(..)
-OperationTree.err.LessParams2=${0} function parameters expected: ${1}(..)
-OperationTree.err.IllegalParam=Illegal parameter ${0} for ${1}(..): ${2} expected
+OperationTree.err.IllegalParam=Illegal parameter ${0} for ${1}(..)\: ${2} expected
+OperationTree.err.BracketsNotClosed=Bracket(s) not closed\: ${0}
+OperationTree.err.MoreParamsExpected=${0} more function parameters expected. Bracket can not close\!

Modified: trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_de.properties
===================================================================
--- trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_de.properties	2010-11-17 11:01:16 UTC (rev 1281)
+++ trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_de.properties	2010-11-17 11:02:14 UTC (rev 1282)
@@ -1,81 +1,80 @@
-##########
-#Copyright (c) 2009 Martin O. J. Schmitz.
-#
-#This file is part of the SCHMITZM library - a collection of utility 
-#classes based on Java 1.6, focusing (not only) on Java Swing 
-#and the Geotools library.
-#
-#The SCHMITZM project is hosted at:
-#http://wald.intevation.org/projects/schmitzm/
-#
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU Lesser General Public License
-#as published by the Free Software Foundation; either version 3
-#of the License, or (at your option) any later version.
-#
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-#
-#You should have received a copy of the GNU Lesser General Public License (license.txt)
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#or try this link: http://www.gnu.org/licenses/lgpl.html
-#
-#Contributors:
-#    Martin O. J. Schmitz - initial API and implementation
-#    Stefan A. Tzeggai - additional utility classes
-##########
-#This file is part of the SCHMITZM library - a collection of utility 
-#classes based on Java 1.6, focussing (not only) on Java Swing 
-#and the Geotools library.
-#
-#The SCHMITZM project is hosted at:
-#http://wald.intevation.org/projects/schmitzm/
-#
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU Lesser General Public License
-#as published by the Free Software Foundation; either version 3
-#of the License, or (at your option) any later version.
-#
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-#
-#You should have received a copy of the GNU Lesser General Public License (license.txt)
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#or try this link: http://www.gnu.org/licenses/lgpl.html
-#
-#Contributors:
-#    Martin O. J. Schmitz - initial API and implementation
-#    Stefan A. Tzeggai - additional utility classes
-##########
-# ------------------------------------------------
-# ------ German Translations for components ------
-# ------ in Package schmitzm.lang           ------
-# ------------------------------------------------
-
-# --- Translations for OperationTree / OperationTreeParser
-OperationTree.Integer=Ganzzahl
+##########
+#Copyright (c) 2009 Martin O. J. Schmitz.
+#
+#This file is part of the SCHMITZM library - a collection of utility 
+#classes based on Java 1.6, focusing (not only) on Java Swing 
+#and the Geotools library.
+#
+#The SCHMITZM project is hosted at:
+#http://wald.intevation.org/projects/schmitzm/
+#
+#This program is free software; you can redistribute it and/or
+#modify it under the terms of the GNU Lesser General Public License
+#as published by the Free Software Foundation; either version 3
+#of the License, or (at your option) any later version.
+#
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#
+#You should have received a copy of the GNU Lesser General Public License (license.txt)
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+#or try this link: http://www.gnu.org/licenses/lgpl.html
+#
+#Contributors:
+#    Martin O. J. Schmitz - initial API and implementation
+#    Stefan A. Tzeggai - additional utility classes
+##########
+#This file is part of the SCHMITZM library - a collection of utility 
+#classes based on Java 1.6, focussing (not only) on Java Swing 
+#and the Geotools library.
+#
+#The SCHMITZM project is hosted at:
+#http://wald.intevation.org/projects/schmitzm/
+#
+#This program is free software; you can redistribute it and/or
+#modify it under the terms of the GNU Lesser General Public License
+#as published by the Free Software Foundation; either version 3
+#of the License, or (at your option) any later version.
+#
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#
+#You should have received a copy of the GNU Lesser General Public License (license.txt)
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+#or try this link: http://www.gnu.org/licenses/lgpl.html
+#
+#Contributors:
+#    Martin O. J. Schmitz - initial API and implementation
+#    Stefan A. Tzeggai - additional utility classes
+##########
+# ------------------------------------------------
+# ------ German Translations for components ------
+# ------ in Package schmitzm.lang           ------
+# ------------------------------------------------
+
+# --- Translations for OperationTree / OperationTreeParser
+
+#Revised by ResourceProviderOperator (Unused keys removed)
+#Wed Nov 17 11:58:09 CET 2010
+OperationTree.err.UnexpectedBracket=Klammer ${0} kann ${1} nicht schliessen
 OperationTree.Number=Numerisch
-OperationTree.err.ParseErrorMess=Parser-Fehler bei "${0}": ${1}
-OperationTree.err.UnexpectedEOR=Unerwartetes Ende der Formel!
-OperationTree.err.UnexpectedError=Unerwarteter Fehler!
+OperationTree.err.UnexpectedEOR=Unerwartetes Ende der Formel\!
+OperationTree.err.UnknownNode=Unbekannter Operator-Knoten\: ${0}
 OperationTree.err.TokenNotExpected=${0} nicht erlaubt
-OperationTree.err.MoreParamsExpected=Noch ${0} Funtionsparameter notwendig. Klammer kann nicht schliessen!
-OperationTree.err.UnexpectedBracket=Klammer ${0} kann ${1} nicht schliessen
-OperationTree.err.BracketsNotClosed=Klammer(n) werden nicht geschlossen: ${0}
-OperationTree.err.IllegalOperator=Ung\u00FCltiger Operator ${0}
+OperationTree.err.LessParams2=${0} Funktionsparameter benötigt\: ${1}(..)
+OperationTree.err.IllegalCharacter=Ungültiges Zeichen '${0}' (${1} erwartet)
+OperationTree.err.UnexpectedError=Unerwarteter Fehler\!
+OperationTree.err.UnknownAliasOperator=Unbekannter Alias-Operator\: ${0}
+OperationTree.err.UnknownOperator=Unbekannter Operator\: ${0}
+OperationTree.err.IllegalOperator=Ungültiger Operator ${0}
+OperationTree.err.ParseErrorMess=Parser-Fehler bei "${0}"\: ${1}
 OperationTree.err.IllegalOperatorSyntax=Fehlerhafte ${0} Syntax '${1}'
-OperationTree.err.ParamSepExpected=Parameter-Trennzeichen erwartet
-OperationTree.err.IllegalCharacter=Ung\u00FCltiges Zeichen '${0}' (${1} erwartet)
-
-OperationTree.err.UnknownNode=Unbekannter Operator-Knoten: ${0}
-OperationTree.err.UnknownOperator=Unbekannter Operator: ${0}
-OperationTree.err.UnknownAliasOperator=Unbekannter Alias-Operator: ${0}
-OperationTree.err.LessParams1=Mindestens ${0} Funktionsparameter ben\u00F6tigt\: ${1}(..)
-OperationTree.err.LessParams2=${0} Funktionsparameter ben\u00F6tigt\: ${1}(..)
-OperationTree.err.IllegalParam=Illegaler Funktionsparameter ${0} f\u00FCr ${1}(..)\: ${2} erwartet
+OperationTree.err.IllegalParam=Illegaler Funktionsparameter ${0} für ${1}(..)\: ${2} erwartet
+OperationTree.err.BracketsNotClosed=Klammer(n) werden nicht geschlossen\: ${0}
+OperationTree.err.MoreParamsExpected=Noch ${0} Funtionsparameter notwendig. Klammer kann nicht schliessen\!

Modified: trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_fr.properties
===================================================================
--- trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_fr.properties	2010-11-17 11:01:16 UTC (rev 1281)
+++ trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_fr.properties	2010-11-17 11:02:14 UTC (rev 1282)
@@ -1,78 +1,78 @@
-##########
-#Copyright (c) 2009 Martin O. J. Schmitz.
-#
-#This file is part of the SCHMITZM library - a collection of utility 
-#classes based on Java 1.6, focusing (not only) on Java Swing 
-#and the Geotools library.
-#
-#The SCHMITZM project is hosted at:
-#http://wald.intevation.org/projects/schmitzm/
-#
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU Lesser General Public License
-#as published by the Free Software Foundation; either version 3
-#of the License, or (at your option) any later version.
-#
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-#
-#You should have received a copy of the GNU Lesser General Public License (license.txt)
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#or try this link: http://www.gnu.org/licenses/lgpl.html
-#
-#Contributors:
-#    Martin O. J. Schmitz - initial API and implementation
-#    Stefan A. Tzeggai - additional utility classes
-##########
-#This file is part of the SCHMITZM library - a collection of utility 
-#classes based on Java 1.6, focussing (not only) on Java Swing 
-#and the Geotools library.
-#
-#The SCHMITZM project is hosted at:
-#http://wald.intevation.org/projects/schmitzm/
-#
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU Lesser General Public License
-#as published by the Free Software Foundation; either version 3
-#of the License, or (at your option) any later version.
-#
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-#
-#You should have received a copy of the GNU Lesser General Public License (license.txt)
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#or try this link: http://www.gnu.org/licenses/lgpl.html
-#
-#Contributors:
-#    Martin O. J. Schmitz - initial API and implementation
-#    Stefan A. Tzeggai - additional utility classes
-##########
-# -----------------------------------------------------------
-# ------ Default Translations (english) for components ------
-# ------ in Package schmitzm.lang                      ------
-# -----------------------------------------------------------
-OperationTree.Integer=Entier
-OperationTree.Number=Num\u00E9rique
-OperationTree.err.BracketsNotClosed=Parenth\u00E8se(s) n'est ou ne sont pas ferm\u00E9e(s)\: ${0}
+##########
+#Copyright (c) 2009 Martin O. J. Schmitz.
+#
+#This file is part of the SCHMITZM library - a collection of utility 
+#classes based on Java 1.6, focusing (not only) on Java Swing 
+#and the Geotools library.
+#
+#The SCHMITZM project is hosted at:
+#http://wald.intevation.org/projects/schmitzm/
+#
+#This program is free software; you can redistribute it and/or
+#modify it under the terms of the GNU Lesser General Public License
+#as published by the Free Software Foundation; either version 3
+#of the License, or (at your option) any later version.
+#
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#
+#You should have received a copy of the GNU Lesser General Public License (license.txt)
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+#or try this link: http://www.gnu.org/licenses/lgpl.html
+#
+#Contributors:
+#    Martin O. J. Schmitz - initial API and implementation
+#    Stefan A. Tzeggai - additional utility classes
+##########
+#This file is part of the SCHMITZM library - a collection of utility 
+#classes based on Java 1.6, focussing (not only) on Java Swing 
+#and the Geotools library.
+#
+#The SCHMITZM project is hosted at:
+#http://wald.intevation.org/projects/schmitzm/
+#
+#This program is free software; you can redistribute it and/or
+#modify it under the terms of the GNU Lesser General Public License
+#as published by the Free Software Foundation; either version 3
+#of the License, or (at your option) any later version.
+#
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#
+#You should have received a copy of the GNU Lesser General Public License (license.txt)
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+#or try this link: http://www.gnu.org/licenses/lgpl.html
+#
+#Contributors:
+#    Martin O. J. Schmitz - initial API and implementation
+#    Stefan A. Tzeggai - additional utility classes
+##########
+# -----------------------------------------------------------
+# ------ Default Translations (english) for components ------
+# ------ in Package schmitzm.lang                      ------
+# -----------------------------------------------------------
+
+#Revised by ResourceProviderOperator (Unused keys removed)
+#Wed Nov 17 11:58:09 CET 2010
+OperationTree.err.UnexpectedBracket=Parenthèse ne ${0} peut ${1} pas se fermer
+OperationTree.Number=Numérique
+OperationTree.err.UnexpectedEOR=Fin de formule inattendue\!
+OperationTree.err.UnknownNode=Noeuds d'opérateurs inconnus\: ${0}
+OperationTree.err.TokenNotExpected=${0} pas autorisé
+OperationTree.err.LessParams2=${0} paramètres de fonction nécessaires\: ${1}(..)
 OperationTree.err.IllegalCharacter=Symbole invalide '${0}' (${1} attendu)");
+OperationTree.err.UnexpectedError=Erreur inattendue\!
+OperationTree.err.UnknownAliasOperator=Alias d'opérateur inconnu\: ${0}
+OperationTree.err.UnknownOperator=Opérateur inconnu\: ${0}
 OperationTree.err.IllegalOperator=Operateur non valide ${0}
-OperationTree.err.IllegalOperatorSyntax=Syntaxe ${0} erron\u00E9e'${1}'
-OperationTree.err.IllegalParam=Faux param\u00E8tres de fonction ${0} attendu pour ${1}(..)\: ${2}
-OperationTree.err.LessParams1=Aumoins ${0} param\u00E8tres de fonction n\u00E9cessaires\: ${1}(..)
-OperationTree.err.LessParams2=${0} param\u00E8tres de fonction n\u00E9cessaires\: ${1}(..)
-OperationTree.err.MoreParamsExpected=Encore ${0} param\u00E8tre(s) de fonction n\u00E9cessaire(s).Parenth\u00E8se ne peut pas se fermer\!
-OperationTree.err.ParamSepExpected= S\u00E9parateur de param\u00E8tres attendu
-OperationTree.err.ParseErrorMess=Erreur d'analyse chez "${0}": ${1}
-OperationTree.err.TokenNotExpected= ${0} pas autoris\u00E9
-OperationTree.err.UnexpectedBracket=Parenth\u00E8se ne ${0} peut ${1} pas se fermer
-OperationTree.err.UnexpectedEOR=Fin de formule inattendue!
-OperationTree.err.UnexpectedError=Erreur inattendue!
-OperationTree.err.UnknownAliasOperator=Alias d'op\u00E9rateur inconnu\: ${0}
-OperationTree.err.UnknownNode=Noeuds d'op\u00E9rateurs inconnus\: ${0}
-OperationTree.err.UnknownOperator=Op\u00E9rateur inconnu\: ${0}
+OperationTree.err.ParseErrorMess=Erreur d'analyse chez "${0}"\: ${1}
+OperationTree.err.IllegalOperatorSyntax=Syntaxe ${0} erronée'${1}'
+OperationTree.err.IllegalParam=Faux paramètres de fonction ${0} attendu pour ${1}(..)\: ${2}
+OperationTree.err.BracketsNotClosed=Parenthèse(s) n'est ou ne sont pas fermée(s)\: ${0}
+OperationTree.err.MoreParamsExpected=Encore ${0} paramètre(s) de fonction nécessaire(s).Parenthèse ne peut pas se fermer\!

Modified: trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_it.properties
===================================================================
--- trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_it.properties	2010-11-17 11:01:16 UTC (rev 1281)
+++ trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_it.properties	2010-11-17 11:02:14 UTC (rev 1282)
@@ -1,55 +1,54 @@
-##########
-#Copyright (c) 2009 Martin O. J. Schmitz.
-#
-#This file is part of the SCHMITZM library - a collection of utility 
-#classes based on Java 1.6, focusing (not only) on Java Swing 
-#and the Geotools library.
-#
-#The SCHMITZM project is hosted at:
-#http://wald.intevation.org/projects/schmitzm/
-#
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU Lesser General Public License
-#as published by the Free Software Foundation; either version 3
-#of the License, or (at your option) any later version.
-#
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-#
-#You should have received a copy of the GNU Lesser General Public License (license.txt)
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#or try this link: http://www.gnu.org/licenses/lgpl.html
-#
-#Contributors:
-#    Annica Sahlin
-##########
-
-# -------------------------------------------------
-# ------ Italian Translations for components ------
-# ------ in Package schmitzm.lang            ------
-# -------------------------------------------------
-
-# --- Translations for OperationTree / OperationTreeParser
-OperationTree.Integer=Integro
+##########
+#Copyright (c) 2009 Martin O. J. Schmitz.
+#
+#This file is part of the SCHMITZM library - a collection of utility 
+#classes based on Java 1.6, focusing (not only) on Java Swing 
+#and the Geotools library.
+#
+#The SCHMITZM project is hosted at:
+#http://wald.intevation.org/projects/schmitzm/
+#
+#This program is free software; you can redistribute it and/or
+#modify it under the terms of the GNU Lesser General Public License
+#as published by the Free Software Foundation; either version 3
+#of the License, or (at your option) any later version.
+#
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#
+#You should have received a copy of the GNU Lesser General Public License (license.txt)
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+#or try this link: http://www.gnu.org/licenses/lgpl.html
+#
+#Contributors:
+#    Annica Sahlin
+##########
+
+# -------------------------------------------------
+# ------ Italian Translations for components ------
+# ------ in Package schmitzm.lang            ------
+# -------------------------------------------------
+
+# --- Translations for OperationTree / OperationTreeParser
+
+#Revised by ResourceProviderOperator (Unused keys removed)
+#Wed Nov 17 11:58:09 CET 2010
+OperationTree.err.UnexpectedBracket=Parentesi ${0} non può essere chiusa ${1}
 OperationTree.Number=Numero
-OperationTree.err.BracketsNotClosed=Parentesi(s) non \u00e8 chiusa: ${0}
+OperationTree.err.UnexpectedEOR=Inaspettata chiusura di rule\!
+OperationTree.err.UnknownNode=Operazione sconosciuta tree node\: ${0}
+OperationTree.err.TokenNotExpected=${0} non richiesto
+OperationTree.err.LessParams2=${0} parametri di funzione richiesti\: ${1}(..)
 OperationTree.err.IllegalCharacter=Carattere non accettato '${0}' (${1} expected)");
+OperationTree.err.UnexpectedError=Errore inaspettato\!
+OperationTree.err.UnknownAliasOperator=Operatore alias non conosciuto\: ${0}
+OperationTree.err.UnknownOperator=Operatore non conosciuto\: ${0}
 OperationTree.err.IllegalOperator=Operatore non accettato ${0}
+OperationTree.err.ParseErrorMess=Errore di analisi in "${0}"\: ${1}
 OperationTree.err.IllegalOperatorSyntax=Sintassi non accettato ${0} '${1}'
-OperationTree.err.IllegalParam=Parametro non accettato ${0} per ${1}(..): ${2} expected
-OperationTree.err.LessParams1=Almeno ${0} parametri di funzione sono richiesti: ${1}(..)
-OperationTree.err.LessParams2=${0} parametri di funzione richiesti: ${1}(..)
-OperationTree.err.MoreParamsExpected= ${0} ulteriori parametri di funzione richiesti. Parentesi non pu\u00f2 essere chiusa!
-OperationTree.err.ParamSepExpected=Separatore di parametro richiesto
-OperationTree.err.ParseErrorMess=Errore di analisi in "${0}": ${1}
-OperationTree.err.TokenNotExpected=${0} non richiesto
-OperationTree.err.UnexpectedBracket=Parentesi ${0} non pu\u00f2 essere chiusa ${1}
-OperationTree.err.UnexpectedEOR=Inaspettata chiusura di rule!
-OperationTree.err.UnexpectedError=Errore inaspettato!
-OperationTree.err.UnknownAliasOperator=Operatore alias non conosciuto: ${0}
-OperationTree.err.UnknownNode=Operazione sconosciuta tree node: ${0}
-OperationTree.err.UnknownOperator=Operatore non conosciuto: ${0}
-
+OperationTree.err.IllegalParam=Parametro non accettato ${0} per ${1}(..)\: ${2} expected
+OperationTree.err.BracketsNotClosed=Parentesi(s) non è chiusa\: ${0}
+OperationTree.err.MoreParamsExpected=${0} ulteriori parametri di funzione richiesti. Parentesi non può essere chiusa\!

Modified: trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_ru.properties
===================================================================
--- trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_ru.properties	2010-11-17 11:01:16 UTC (rev 1281)
+++ trunk/src_junit/schmitzm/lang/resource/locales/TestLangResourceBundle_ru.properties	2010-11-17 11:02:14 UTC (rev 1282)
@@ -1,57 +1,57 @@
-#-------------------------------------------------------------------------------
-# Copyright (c) 2010 Stefan A. Tzeggai.
-# All rights reserved. This program and the accompanying materials
-# are made available under the terms of the GNU Lesser Public License v2.1
-# which accompanies this distribution, and is available at
-# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# 
-# Contributors:
-#     Stefan A. Tzeggai - initial API and implementation
-#-------------------------------------------------------------------------------
-##########
-#Copyright (c) 2009 Stefan A. Tzeggai.
-#
-#This file is part of the AtlasViewer application - A GIS viewer application targeting at end-users with no GIS-experience. Its main purpose is to present the atlases created with the Geopublisher application.
-#http://www.geopublishing.org
-#
-#AtlasViewer is part of the Geopublishing Framework hosted at:
-#http://wald.intevation.org/projects/atlas-framework/
-#
-#This program is free software; you can redistribute it and/or
-#modify it under the terms of the GNU Lesser General Public License
-#as published by the Free Software Foundation; either version 3
-#of the License, or (at your option) any later version.
-#
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-#
-#You should have received a copy of the GNU Lesser General Public License (license.txt)
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#or try this link: http://www.gnu.org/licenses/lgpl.html
-#
-#Contributors:
-#    Lazarev Evgeny, FGUP UralGeoInform
-##########
-
-OperationTree.err.BracketsNotClosed=\u0421\u043A\u043E\u0431\u043A\u0430(\u0438) \u043D\u0435 \u0437\u0430\u043A\u0440\u044B\u0442\u0430(\u044B)\: ${0}
-OperationTree.err.IllegalCharacter=\u041D\u0435 \u0432\u0435\u0440\u043D\u044B\u0439 \u0441\u0438\u043C\u0432\u043E\u043B '${0}' (\u043E\u0436\u0438\u0434\u0430\u043B\u0441\u044F ${1})");
-OperationTree.err.IllegalOperatorSyntax=\u041D\u0435 \u0432\u0435\u0440\u043D\u044B\u0439 ${0} \u0441\u0438\u043D\u0442\u0430\u043A\u0441\u0438\u0441 '${1}'
-OperationTree.err.IllegalOperator=\u041D\u0435 \u0432\u0435\u0440\u043D\u044B\u0439 \u043E\u043F\u0435\u0440\u0430\u0442\u043E\u0440 ${0}
-OperationTree.err.IllegalParam=\u041D\u0435 \u0432\u0435\u0440\u043D\u044B\u0439 \u043F\u0430\u0440\u0430\u043C\u0435\u0442\u0440 ${0} \u0434\u043B\u044F ${1}(..)\: \u043E\u0436\u0438\u0434\u0430\u043B\u0441\u044F ${2}
-OperationTree.err.LessParams1=\u041E\u0436\u0438\u0434\u0430\u043B\u043E\u0441\u044C \u043A\u0430\u043A \u043C\u0438\u043D\u0438\u043C\u0443\u043C ${0} \u043F\u0430\u0440\u0430\u043C\u0435\u0442\u0440\u043E\u0432 \u0444\u0443\u043D\u043A\u0446\u0438\u0438\: ${1}(..)
-OperationTree.err.LessParams2=\u041E\u0436\u0430\u0434\u0430\u043B\u043E\u0441\u044C ${0} \u043F\u0430\u0440\u0430\u043C\u0435\u0442\u0440\u043E\u0432 \u0444\u0443\u043D\u043A\u0446\u0438\u0438\: ${1}(..)
-OperationTree.err.MoreParamsExpected=\u041E\u0436\u0438\u0434\u0430\u043B\u043E\u0441\u044C \u0431\u043E\u043B\u0435\u0435 ${0} \u043F\u0430\u0440\u0430\u043C\u0435\u0442\u0440\u043E\u0432 \u0444\u0443\u043D\u043A\u0446\u0438\u0438. \u0421\u043A\u043E\u0431\u043A\u0430 \u043D\u0435 \u043C\u043E\u0436\u0435\u0442 \u0431\u044B\u0442\u044C \u0437\u0430\u043A\u0440\u044B\u0442\u0430\!
-OperationTree.err.ParamSepExpected=\u041E\u0436\u0438\u0434\u0430\u043B\u0441\u044F \u0440\u0430\u0437\u0434\u0435\u043B\u0438\u0442\u0435\u043B\u044C \u043F\u0430\u0440\u0430\u043C\u0435\u0442\u0440\u043E\u0432
-OperationTree.err.ParseErrorMess=\u041E\u0448\u0438\u0431\u043A\u0430 \u0440\u0430\u0437\u043E\u0431\u0440\u0430 \u0432 "${0}"\: ${1}
-OperationTree.err.TokenNotExpected=\u041D\u0435 \u043E\u0436\u0438\u0434\u0430\u043B\u0441\u044F ${0}
-OperationTree.err.UnexpectedBracket=\u0421\u043A\u043E\u0431\u043A\u0430 ${0} \u043D\u0435 \u043C\u043E\u0436\u0435\u0442 \u0437\u0430\u043A\u0440\u044B\u0432\u0430\u0442\u044C ${1}
-OperationTree.err.UnexpectedEOR=\u041D\u0435\u043E\u0436\u0438\u0434\u0430\u043D\u043D\u044B\u0439 \u043A\u043E\u043D\u0435\u0446 \u043F\u0440\u0430\u0432\u0438\u043B\u0430\!
-OperationTree.err.UnexpectedError=\u041D\u0435\u043E\u0436\u0438\u0434\u0430\u043D\u043D\u0430\u044F \u043E\u0448\u0438\u0431\u043A\u0430\!
-OperationTree.err.UnknownAliasOperator=\u041D\u0435\u0438\u0437\u0432\u0435\u0441\u0442\u043D\u044B\u0439 \u043E\u043F\u0435\u0440\u0430\u0442\u043E\u0440 \u043C\u0435\u0442\u043A\u0438\: ${0}
-OperationTree.err.UnknownNode=\u041D\u0435\u0438\u0437\u0432\u0435\u0441\u0442\u043D\u044B\u0439 \u043E\u043F\u0435\u0440\u0430\u0446\u0438\u044F \u043D\u0430 \u0432\u0435\u0442\u043A\u0435\: ${0}
-OperationTree.err.UnknownOperator=\u041D\u0435\u0438\u0437\u0432\u0435\u0441\u0442\u043D\u044B\u0439 \u043E\u043F\u0435\u0440\u0430\u0442\u043E\u0440\: ${0}
-OperationTree.Integer=\u0426\u0435\u043B\u043E\u0435
-OperationTree.Number=\u0427\u0438\u0441\u043B\u043E
+#-------------------------------------------------------------------------------
+# Copyright (c) 2010 Stefan A. Tzeggai.
+# All rights reserved. This program and the accompanying materials
+# are made available under the terms of the GNU Lesser Public License v2.1
+# which accompanies this distribution, and is available at
+# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+# 
+# Contributors:
+#     Stefan A. Tzeggai - initial API and implementation
+#-------------------------------------------------------------------------------
+##########
+#Copyright (c) 2009 Stefan A. Tzeggai.
+#
+#This file is part of the AtlasViewer application - A GIS viewer application targeting at end-users with no GIS-experience. Its main purpose is to present the atlases created with the Geopublisher application.
+#http://www.geopublishing.org
+#
+#AtlasViewer is part of the Geopublishing Framework hosted at:
+#http://wald.intevation.org/projects/atlas-framework/
+#
+#This program is free software; you can redistribute it and/or
+#modify it under the terms of the GNU Lesser General Public License
+#as published by the Free Software Foundation; either version 3
+#of the License, or (at your option) any later version.
+#
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#
+#You should have received a copy of the GNU Lesser General Public License (license.txt)
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+#or try this link: http://www.gnu.org/licenses/lgpl.html
+#
+#Contributors:
+#    Lazarev Evgeny, FGUP UralGeoInform
+##########
+
+
+#Revised by ResourceProviderOperator (Unused keys removed)
+#Wed Nov 17 11:58:09 CET 2010
+OperationTree.err.UnexpectedBracket=Скобка ${0} не может закрывать ${1}
+OperationTree.Number=Число
+OperationTree.err.UnexpectedEOR=Неожиданный конец правила\!
+OperationTree.err.UnknownNode=Неизвестный операция на ветке\: ${0}
+OperationTree.err.TokenNotExpected=Не ожидался ${0}
+OperationTree.err.LessParams2=Ожадалось ${0} параметров функции\: ${1}(..)
+OperationTree.err.IllegalCharacter=Не верный символ '${0}' (ожидался ${1})");
+OperationTree.err.UnexpectedError=Неожиданная ошибка\!
+OperationTree.err.UnknownAliasOperator=Неизвестный оператор метки\: ${0}
+OperationTree.err.UnknownOperator=Неизвестный оператор\: ${0}
+OperationTree.err.IllegalOperator=Не верный оператор ${0}
+OperationTree.err.ParseErrorMess=Ошибка разобра в "${0}"\: ${1}
+OperationTree.err.IllegalOperatorSyntax=Не верный ${0} синтаксис '${1}'
+OperationTree.err.IllegalParam=Не верный параметр ${0} для ${1}(..)\: ожидался ${2}
+OperationTree.err.BracketsNotClosed=Скобка(и) не закрыта(ы)\: ${0}
+OperationTree.err.MoreParamsExpected=Ожидалось более ${0} параметров функции. Скобка не может быть закрыта\!



More information about the Schmitzm-commits mailing list
--- trunk/src/schmitzm/lang/ResourceProviderOperator.java	2010-11-17 11:01:16 UTC (rev 1281)
+++ trunk/src/schmitzm/lang/ResourceProviderOperator.java	2010-11-17 11:02:14 UTC (rev 1282)
@@ -298,7 +298,7 @@
   /**
    * Removes a set of keys from only the specified locale and rewrites the
    * bundle file in the source folder. The removed key/value pairs are
    * archived in a {@code .removedKeys} file.
    * @param rp resource provider to process
    * @param locale locale to process
    * @param set of keys to remove
@@ -348,8 +348,8 @@
     if ( removedKeys.size() > 0 ) {
       // store remaining pairs
       String comments = getInitialCommentLines(bundleFile, "#", true);
-//      Writer remainingKeysOutput = IOUtil.createUTF8FileWriter(bundleFile,false);
-      Writer remainingKeysOutput = IOUtil.createUTF8FileWriter( IOUtil.changeFileExt(bundleFile, "remainingKeys"), false );
+      Writer remainingKeysOutput = IOUtil.createUTF8FileWriter(bundleFile,false);
+//      Writer remainingKeysOutput = IOUtil.createUTF8FileWriter( IOUtil.changeFileExt(bundleFile, "remainingKeys"), false );
       remainingKeysOutput.write(comments); // write comments as their were
       if ( !"".equals(comments) )
         remainingKeysOutput.write("\n");
@@ -360,7 +360,7 @@
       remainingKeysOutput.close();
         
       // store removed pairs
-      File removedKeysFile = IOUtil.changeFileExt(bundleFile, "removedKeys");
+      File removedKeysFile = IOUtil.changeFileExt(bundleFile, "removedKeys.properties");
       Writer removedKeysOutput = IOUtil.createUTF8FileWriter(removedKeysFile,true);
       removedKeys.store(
           removedKeysOutput,
@@ -483,7 +483,7 @@
     LangUtil.initializeDefaultLogger(Level.DEBUG,null);
     initCliOptions();
     try {
-    cliOptionValues = cliParser.parse(cliOptions, args);
+      cliOptionValues = cliParser.parse(cliOptions, args);
     } catch (UnrecognizedOptionException err) {
       LOGGER.error(err.getMessage()+"\n");
       printCliHelp();
@@ -552,8 +552,6 @@
       String resourceBundleRootFolder = parameters.getProperty(CFG_KEY_RESOURCE_BUNDLES_ROOT_FOLDER);
       if ( resourceBundleRootFolder != null )
         rpo.setResourceBundlesRootFolder(new File(resourceBundleRootFolder));
-      else
-        rpo.setResourceBundlesRootFolder(new File("."));
       String resourceBundlesList = parameters.getProperty(CFG_KEY_RESOURCE_BUNDLES);
       if ( resourceBundlesList != null ) {
         String[] resourceBundles = resourceBundlesList.split(""+RESOURCE_BUNDLES_SEP);
@@ -298,7 +298,7 @@
    * Removes a set of keys from only the specified locale and rewrites the
    * bundle file in the source folder. The removed key/value pairs are
-   * archived in a {@code .removedKeys} file.
+   * archived in a {@code .removedKeys.properties} file.
    * @param rp resource provider to process
    * @param locale locale to process

Modified: trunk/src_junit/schmitzm/lang/ResourceProviderTest.java
===================================================================